@@ -27,7 +27,7 @@ class Version(resource.Resource):
     updated = resource.Body('updated')
 
     @classmethod
-    def list(cls, session, paginated=False, **params):
+    def list(cls, session, paginated=False, base_path=None, **params):
         resp = session.get(cls.base_path,
                            params=params)
         resp = resp.json()
